import {
  APIRequest,
  APIResponse,
  APIEncoder,
  APIDecoder,
  ParameterUtil
} from '@ucap-webmessenger/api';
import { DeviceType } from '@ucap-webmessenger/core';
import { MessageType } from '../types/message.type';
import { MessageList } from '../models/message-list';

export interface RetrieveRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  type: MessageType;
  pageSize: number;
  pageCount: number;
}

export interface RetrieveSendResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
  totalCount: number;

  messageList: MessageList[];
}

const RetrieveSendEncodeMap = {};

export const encodeRetrieve: APIEncoder<RetrieveRequest> = (
  req: RetrieveRequest
) => {
  return ParameterUtil.encode(RetrieveSendEncodeMap, req);
};

export const decodeRetrieveSend: APIDecoder<RetrieveSendResponse> = (
  res: any
) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveSendResponse;
};
